// A basic OpenGL program displaying a 2D house shape

#include <windows.h>
#include <gl/gl.h>
#include <gl/glu.h>
#include <gl/glut.h>

const int windowWidth=300;
const int windowHeight=400;

// define vertices and edges of the house
const int numVertices=5;
const int numEdges=6;
const float vertices[numVertices][2] =  {{0.0,0.0},{100.0,0.0},{0.0,100.0},{100.0,100.0},{50.0,150.0}};
const int edges[numEdges][2] = {{0,1},{1,3},{3,2},{2,0},{2,4},{3,4}};

void display(void)
{
	// clear all pixels in frame buffer
	glClear(GL_COLOR_BUFFER_BIT);

	// draw edges of house in red
	glColor3f (1.0, 0.0, 0.0);	// (red,green,blue) colour components

	glBegin(GL_LINES);
	for(int i=0;i<numEdges;i++)
	{
		glVertex2fv(vertices[edges[i][0]]);
		glVertex2fv(vertices[edges[i][1]]);
	}
	glEnd();

	// start processing buffered OpenGL routines 
	glFlush ();
}

void init(void) 
{
	// select clearing color (for glClear)
	glClearColor (1.0, 1.0, 1.0, 0.0);	// RGB-value for white

	// initialize view (simple orthographic projection)
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	GLdouble halfWidth=(GLdouble) windowWidth/2.0;
	GLdouble halfHeight=(GLdouble) windowHeight/2.0;
	gluOrtho2D(-halfWidth, halfWidth, -halfHeight, halfHeight);
}

// create a single buffered colour window
int main(int argc, char** argv)
{
	glutInit(&argc, argv);		
	glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);
	glutInitWindowSize(windowWidth, windowHeight); 
	glutInitWindowPosition(100, 100);
	glutCreateWindow("My first OpenGL program");
	init ();						// initialise view
	glutDisplayFunc(display);		// draw scene
	glutMainLoop();
	return 0;
}
